==> haskell-hosc-0.17-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hosc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hosc
version: 0.17
id: hosc-0.17-LFOlAZTinFv6HirFuBJFC1
key: hosc-0.17-LFOlAZTinFv6HirFuBJFC1
license: GPL-3.0-only
copyright: (c) Rohan Drape, Stefan Kersten and others, 2007-2018
maintainer: rd@rohandrape.net
author: Rohan Drape, Stefan Kersten
stability: Experimental
homepage: http://rohandrape.net/t/hosc
synopsis: Haskell Open Sound Control
description:
    @hosc@ implements a subset of the Open Sound Control
    byte protocol, <http://opensoundcontrol.org/>.
    .
    See "Sound.OSC.Core" or "Sound.OSC" or "Sound.OSC.FD".
category: Sound
abi: 3587ff13a037cd607eed7d7f37b7a16c
exposed: True
exposed-modules:
    Sound.OSC Sound.OSC.Coding.Byte Sound.OSC.Coding.Cast
    Sound.OSC.Coding.Convert Sound.OSC.Coding.Decode.Base
    Sound.OSC.Coding.Decode.Binary Sound.OSC.Coding.Encode.Base
    Sound.OSC.Coding.Encode.Builder Sound.OSC.Core Sound.OSC.Datum
    Sound.OSC.FD Sound.OSC.Packet Sound.OSC.Time Sound.OSC.Transport.FD
    Sound.OSC.Transport.FD.TCP Sound.OSC.Transport.FD.UDP
    Sound.OSC.Transport.Monad Sound.OSC.Wait
import-dirs: /usr/lib/ghc-8.6.5/site-local/hosc-0.17
library-dirs: /usr/lib/ghc-8.6.5/site-local/hosc-0.17
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hosc-0.17
hs-libraries: HShosc-0.17-LFOlAZTinFv6HirFuBJFC1
depends:
    base-4.12.0.0 binary-0.8.6.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    data-binary-ieee754-0.4.4-Jh3qq4jPu7AAxCF7JMXnJo
    network-2.8.0.0-LvSlvEKiGr81Yl4BCXERfa time-1.8.0.2
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hosc/html/hosc.haddock
haddock-html: /usr/share/doc/haskell-hosc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hosc-0.17-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hosc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hosc
version: 0.17
id: hosc-0.17-rtNsvBl0hoKOcIiiWeQFI
key: hosc-0.17-rtNsvBl0hoKOcIiiWeQFI
license: GPL-3.0-only
copyright: (c) Rohan Drape, Stefan Kersten and others, 2007-2018
maintainer: rd@rohandrape.net
author: Rohan Drape, Stefan Kersten
stability: Experimental
homepage: http://rohandrape.net/t/hosc
synopsis: Haskell Open Sound Control
description:
    @hosc@ implements a subset of the Open Sound Control
    byte protocol, <http://opensoundcontrol.org/>.
    .
    See "Sound.OSC.Core" or "Sound.OSC" or "Sound.OSC.FD".
category: Sound
abi: 9474e916ab484301a13febea7d67edf4
exposed: True
exposed-modules:
    Sound.OSC Sound.OSC.Coding.Byte Sound.OSC.Coding.Cast
    Sound.OSC.Coding.Convert Sound.OSC.Coding.Decode.Base
    Sound.OSC.Coding.Decode.Binary Sound.OSC.Coding.Encode.Base
    Sound.OSC.Coding.Encode.Builder Sound.OSC.Core Sound.OSC.Datum
    Sound.OSC.FD Sound.OSC.Packet Sound.OSC.Time Sound.OSC.Transport.FD
    Sound.OSC.Transport.FD.TCP Sound.OSC.Transport.FD.UDP
    Sound.OSC.Transport.Monad Sound.OSC.Wait
import-dirs: /usr/lib/ghc-8.6.5/site-local/hosc-0.17
library-dirs: /usr/lib/ghc-8.6.5/site-local/hosc-0.17
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hosc-0.17
hs-libraries: HShosc-0.17-rtNsvBl0hoKOcIiiWeQFI
depends:
    base-4.12.0.0 binary-0.8.6.0
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    data-binary-ieee754-0.4.4-Jh3qq4jPu7AAxCF7JMXnJo
    network-2.8.0.1-L17Rv8Nouqq1qZnRto8DBo time-1.8.0.2
    transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-hosc/html/hosc.haddock
haddock-html: /usr/share/doc/haskell-hosc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
